@@ -29,7 +29,6 @@ from dkist_header_validator.exceptions import ReturnTypeException
 from dkist_header_validator.exceptions import SpecSchemaDefinitionException
 from dkist_header_validator.exceptions import SpecValidationException
 from dkist_header_validator.exceptions import ValidationException
-from dkist_header_validator.translator import translate_spec122_to_spec214
 from dkist_header_validator.translator import translate_spec122_to_spec214_l0
 
 
@@ -81,7 +80,7 @@ class FITSFloatInvalid(Invalid):
     """
 
 
-class FITSFloatValidsator:
+class FITSFloatValidator:
     """
     Validate a FITS floating point value.
 
@@ -108,6 +107,7 @@ class SpecSchema:
         vol.Required("required"): vol.Any(True, False),
         vol.Required("type"): vol.Any("int", "float", "str", "bool"),
         "values": list,
+        "values_range": list,
         "expected": vol.Any(True, False),
         "expand": vol.Any(True, False),
         "format": vol.Any("unit", "isot"),
@@ -167,7 +167,7 @@ class SpecSchema:
             except vol.MultipleInvalid as e:
                 schema_errors = {error.path[0]: error.msg for error in e.errors}
             if schema_errors:
-                logger.error(
+                logger.debug(
                     f"Errors during schema definition validation. key={key} errors={schema_errors}"
                 )
                 raise SpecSchemaDefinitionException(
@@ -202,14 +202,34 @@ class SpecSchema:
         # Always check type
         checks.append(type_map[key_schema.get("type")])
 
+        def case_insenstive_values(value):
+            allowed_values = key_schema.get("values")
+            if key_schema.get("type") == "str":
+                value = value.lower()
+                allowed_values = [v.lower() for v in allowed_values]
+
+            return vol.Any(*allowed_values)(value)
+
+        def expand_values_range(value):
+            min_value = key_schema.get("values_range")[0]
+            try:
+                max_value = key_schema.get("values_range")[1]
+            except IndexError:
+                max_value = None
+
+            return vol.Range(min=min_value, max=max_value)(value)
+
         if key_schema.get("values"):
-            checks.append(vol.Any(*key_schema.get("values")))
+            checks.append(case_insenstive_values)
+
+        if key_schema.get("values_range"):
+            checks.append(expand_values_range)
 
         if "format" in key_schema:
             checks.append(FormatValidator(key_schema["format"]))
 
         if key_schema.get("type") == "float":
-            checks.append(FITSFloatValidsator())
+            checks.append(FITSFloatValidator())
 
         return vol.All(*checks)
 
@@ -259,6 +279,10 @@ class SpecSchema:
         :param headers: header dict to validate
         :return: vol.Schema
         """
+        """for value in self.spec_schema_definitions.values():
+            if value["values_range"]:
+                pass"""
+
         spec_schema = self._create_spec_schema(headers, extra)
         return spec_schema(headers)
 
@@ -352,9 +376,9 @@ class SpecValidator:
                 ],
             ):
                 if len(sublist) > 0:
-                    logger.error(f"\n{message}")
+                    logger.debug(f"\n{message}")
                     for k in sorted(sublist):
-                        logger.error(f"{str(k):<10}:\t{validation_errors[k]}")
+                        logger.debug(f"{str(k):<10}:\t{validation_errors[k]}")
 
             raise self.SchemaValidationException(errors=validation_errors)
         logger.debug("Schema validation succeeded")
@@ -411,7 +435,7 @@ class SpecValidator:
                 verified_headers = self.verify_headers(hdus, extra)
                 return verified_headers, fits_cards, data
         except (ValueError, FileNotFoundError, OSError, IndexError) as exc:
-            logger.error(f"Cannot parse headers: detail = {exc}")
+            logger.debug(f"Cannot parse headers: detail = {exc}")
             raise ValidationException(f"Cannot parse headers", errors={type(exc): str(exc)})
 
     @staticmethod
@@ -496,7 +520,7 @@ class SpecValidator:
             output_verify="exception",
             checksum=True,
         )
-        return os.path.basename(input_headers)
+        return Path(os.path.basename(input_headers))
 
     @staticmethod
     def _return_HDU(validated_headers, data, fits_cards):
@@ -529,8 +553,10 @@ class SpecValidator:
             return self._return_BytesIO(validated_headers, input_headers, data, fits_cards)
         if return_type == dict:
             return self._return_dictionary(validated_headers, fits_cards)
-        if return_type == HDUList or return_type == fits.header.Header:
+        if return_type == HDUList:
             return self._return_hdulist(validated_headers, fits_cards)
+        if return_type == fits.header.Header:
+            return self._return_HDU(validated_headers, data, fits_cards).header
         if return_type == fits.PrimaryHDU:
             if data is None:
                 raise ReturnTypeException("No data. Cannot write PrimaryHDU.")
@@ -613,35 +639,3 @@ class SpecValidator:
             return self._format_output(
                 return_type, translated_headers, input_headers, data, fits_cards
             )
-
-    def validate_and_translate_to_214(self, input_headers, return_type=HDUList, extra=True):
-        """
-        Validates against the instance spec_schema and then translates to the full spec214 schema
-        :param input_headers: The headers to validate in the following formats:
-            - string file path
-            - File like object
-            - HDUList object
-            - fits.header.Header object
-            - Dictionary of header keys and values
-        :param return_type: determines return type. Default is HDUList. May be one of:
-            - dict
-            - BytesIO
-            - fits.header.Header
-            - Path (file)
-            - HDUList
-            - fits.PrimaryHDU
-        :param extra: switch for validation to allow extra keys in schema. Default is true, which will
-        allow extra keys. Ingest validation should allow extra keys.
-        :return: formatted 214 headers
-        :raises: SpecValidationException or subclass
-        """
-        if isinstance(input_headers, (dict, fits.header.Header, HDUList)):
-            validated_headers, fits_cards = self._validate_headers(input_headers, extra)
-            translated_headers = translate_spec122_to_spec214(validated_headers)
-            return self._format_output(return_type, translated_headers, None, None, fits_cards)
-        else:
-            validated_headers, fits_cards, data = self._validate_file(input_headers, extra)
-            translated_headers = translate_spec122_to_spec214(validated_headers)
-            return self._format_output(
-                return_type, translated_headers, input_headers, data, fits_cards
-            )
